@@ -23,7 +23,8 @@ class _MultiWindowPlot:
         assert isinstance(nrows, int) or (nrows is None), "nrows should be an integer or None"
         assert isinstance(ncols, int) or (ncols is None), "ncols should be an integer or None"
         assert isinstance(figsize, Iterable) or (figsize is None), "figsize should be a list or tuple of 2 integers"
-        assert len(figsize) == 2, "figsize should be a list or tuple of 2 integers"
+        if isinstance(figsize, Iterable):
+            assert len(figsize) == 2, "figsize should be a list or tuple of 2 integers"
         if isinstance(figsize, Iterable):
             for o in figsize:
                 assert isinstance(o, int), "figsize should be a list or tuple of 2 integers"
@@ -75,7 +76,7 @@ class _MultiWindowPlot:
         return self.fig, ax
 
     def finish(self, filename, dpi):
-        """Finish the plot with given filename and dpi
+        """Finish the plot with given filename and dpi.
 
         :param filename: None, or path to target file (if None, (fig, ax) will be returned
         :param dpi: dpi setting to use when path is specified
@@ -90,7 +91,7 @@ class _MultiWindowPlot:
 
 
 def _recompute_maf(d, phenotypenames):
-    """Helper function to compute overall MAF
+    """Helper function to compute overall MAF.
 
     :param d: dataset
     :type d: pandas.DataFrame
@@ -103,11 +104,11 @@ def _recompute_maf(d, phenotypenames):
     ns, mafs = [], []
     for ncol in ncols:
         if ncol not in d.columns:
-            ns.append(np.repeat(1, len(d)).reshape((len(d), 1)))
+            ns.append(np.repeat(0, len(d)).reshape((len(d), 1)))
         else:
-            ns.append(d[ncol].to_numpy().reshape((len(d), 1)))
+            ns.append(d[ncol].fillna(0).values.reshape((len(d), 1)))
     for mafcol in mafcols:
-        mafs.append(d[mafcol].to_numpy().reshape((len(d), 1)))
+        mafs.append(d[mafcol].fillna(0).values.reshape((len(d), 1)))
     mafs = np.concatenate(mafs, axis=1)
     ns = np.concatenate(ns, axis=1)
     return (mafs * ns).sum(axis=1)/ns.sum(axis=1)
